@@ -1,23 +1,36 @@
 
 #define HOST_CPU "i386"
 #define HOST_VENDOR "pc"
-#define HOST_OS "bsdi4.1"
+#define HOST_OS "bsdi4.2"
 #define HOST_OS_NAME "bsdi4"
-#define HOST_OS_VERSION "4.1"
+#define HOST_OS_VERSION "4.2"
 #define HOST_ARCH "i386"
-#define HOST_NAME "cricket.mcl.cs.columbia.edu"
+#define HOST_NAME "a-bsdi42.fsl.cs.sunysb.edu"
 #define USER_NAME "ezk"
-#define CONFIG_DATE "Sun Jan 16 18:12:52 EST 2000"
+#define CONFIG_DATE "Wed Nov 14 19:18:58 EST 2001"
 #define PACKAGE "am-utils"
-#define VERSION "6.0.3s3"
+#define VERSION "6.0.8s1"
 #define PACKAGE "am-utils"
-#define VERSION "6.0.3s3"
+#define VERSION "6.0.8s1"
 #define DEBUG 1
-#define HOST_HEADER_VERSION "4.1"
+#define STDC_HEADERS 1
+#define HAVE_SYS_TYPES_H 1
+#define HAVE_SYS_STAT_H 1
+#define HAVE_STDLIB_H 1
+#define HAVE_STRING_H 1
+#define HAVE_MEMORY_H 1
+#define HAVE_STRINGS_H 1
+#define HAVE_UNISTD_H 1
+#define HAVE_DLFCN_H 1
+#define HOST_HEADER_VERSION "4.2"
 #define HAVE_LIBRPC 1
 #define HAVE_LIBRPCSVC 1
 #define HAVE_ALLOCA 1
-#define STDC_HEADERS 1
+#define HAVE_UNISTD_H 1
+#define HAVE_FORK 1
+#define HAVE_VFORK 1
+#define HAVE_WORKING_VFORK 1
+#define HAVE_WORKING_FORK 1
 #define HAVE_WAIT3 1
 #define HAVE__SETERR_REPLY 1
 #define HAVE_BCMP 1
@@ -25,6 +38,7 @@
 #define HAVE_BZERO 1
 #define HAVE_CLNT_CREATE 1
 #define HAVE_CLNT_SPCREATEERROR 1
+#define HAVE_CLOCK_GETTIME 1
 #define HAVE_FLOCK 1
 #define HAVE_GET_MYADDRESS 1
 #define HAVE_GETCWD 1
@@ -191,7 +205,6 @@
 #define HAVE_VARARGS_H 1
 #define HAVE_UNISTD_H 1
 #define TIME_WITH_SYS_TIME 1
-#define HAVE_ST_RDEV 1
 #define AMU_NFS_PROTOCOL_HEADER "../conf/nfs_prot/nfs_prot_bsdi3.h"
 #define HAVE_STRUCT_NFS_ARGS 1
 #define nfs_args_t struct nfs_args
@@ -236,6 +249,7 @@
 #define HAVE_EXTERN_WAIT3 1
 #define HAVE_EXTERN_VSNPRINTF 1
 #define HAVE_LONG_FILE_NAMES 1
+#define HAVE_UNISTD_H 1
 #define HAVE_RESTARTABLE_SYSCALLS 1
 #define HAVE_FIELD_CDFS_ARGS_T_FLAGS 1
 #define HAVE_FIELD_CDFS_ARGS_T_FSPEC 1
@@ -266,18 +280,18 @@
 #define HAVE_FS_TFS 1
 #define HAVE_FS_UFS 1
 #define HAVE_FS_UNIONFS 1
-#define HAVE_AM_FS_AUTO 1
-#define HAVE_AM_FS_DIRECT 1
-#define HAVE_AM_FS_TOPLVL 1
-#define HAVE_AM_FS_ERROR 1
-#define HAVE_AM_FS_INHERIT 1
-#define HAVE_AM_FS_PROGRAM 1
-#define HAVE_AM_FS_LINK 1
-#define HAVE_AM_FS_LINKX 1
-#define HAVE_AM_FS_HOST 1
-#define HAVE_AM_FS_NFSX 1
-#define HAVE_AM_FS_NFSL 1
-#define HAVE_AM_FS_UNION 1
+#define HAVE_AMU_FS_AUTO 1
+#define HAVE_AMU_FS_DIRECT 1
+#define HAVE_AMU_FS_TOPLVL 1
+#define HAVE_AMU_FS_ERROR 1
+#define HAVE_AMU_FS_INHERIT 1
+#define HAVE_AMU_FS_PROGRAM 1
+#define HAVE_AMU_FS_LINK 1
+#define HAVE_AMU_FS_LINKX 1
+#define HAVE_AMU_FS_HOST 1
+#define HAVE_AMU_FS_NFSX 1
+#define HAVE_AMU_FS_NFSL 1
+#define HAVE_AMU_FS_UNION 1
 #define MOUNT_TYPE_NFS "nfs"
 #define MOUNT_TYPE_NFS3 MNTTYPE_NFS3
 #define MOUNT_TYPE_UFS "ufs"
@@ -305,12 +319,15 @@
 #define MNT2_NFS_OPT_DEADTHRESH 0x4000
 #define MNT2_NFS_OPT_DUMBTIMR 0x800
 #define MNT2_NFS_OPT_INT 0x40
+#define MNT2_NFS_OPT_KERB 0x400
 #define MNT2_NFS_OPT_LEASETERM 0x1000
 #define MNT2_NFS_OPT_MAXGRPS 0x20
 #define MNT2_NFS_OPT_NFSV3 0x200
 #define MNT2_NFS_OPT_NOCONN 0x80
 #define MNT2_NFS_OPT_NQNFS 0x100
+#define MNT2_NFS_OPT_RDIRPLUS 0x10000
 #define MNT2_NFS_OPT_READAHEAD 0x2000
+#define MNT2_NFS_OPT_READDIRSIZE 0x20000
 #define MNT2_NFS_OPT_RESVPORT 0x8000
 #define MNT2_NFS_OPT_RETRANS 0x10
 #define MNT2_NFS_OPT_RSIZE 0x4
